@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import List, Callable, Dict, Any, Optional, Union
+from typing import List, Callable, Dict, Any, Optional, Union, Tuple
 
 from movado.controller import Controller
 from movado.estimator import Estimator
@@ -39,7 +39,7 @@ class MabController(Controller):
         self.__mab = MabHandlerCB(
             arms=2,
             debug=debug,
-            cover=3,
+            cover=cover,
             controller_params={self.__params[0]: self.__params[1]},
         )
         self.__weight_mab = None
@@ -62,10 +62,19 @@ class MabController(Controller):
         )
 
     def compute_objective(
-        self, point: List[int], decision_only: bool = False
-    ) -> Union[List[float], int]:
-        decision = self.__mab.predict(self._compute_controller_context(point))
+        self,
+        point: List[int],
+        decision_only: bool = False,
+        probability=False,
+    ) -> Union[List[float], int, Tuple[int, float]]:
+        decision = self.__mab.predict(
+            self._compute_controller_context(point), probability=probability
+        )
         accuracy = self._estimator.get_error()
+        if probability:
+            return (
+                (decision[0] - 1, decision[1]) if accuracy != 0.0 else (1, decision[1])
+            )
         if decision_only:
             return decision - 1
         if decision == 2 or accuracy == 0.0:
@@ -86,7 +95,7 @@ class MabController(Controller):
             self.write_debug(
                 {
                     "Model_Parameters": {
-                        "epsilon": self.__epsilon,
+                        "epsilon": self.__cover,
                         "cover": self.__cover,
                     },
                     "Point": point,
